Steps for Setup:
    1. If everything install right than you just have to go to your command prompt or bash and type
        Bitcoin_Price
    else do this
    1. Open dir and go in Bitcoin_Price->BitcoinPrice, here you can see Bitcoin_Price.py file.
    2. Save the above path as system path by going as
        System properties->Advance system setting->Environmental Variables
        Here left click on path and then left click on Edit.
        Then save the path.
        You can follow this link: https://www.youtube.com/watch?v=Y2q_b4ugPWk for window
                                  https://www.youtube.com/watch?v=abN6bvyPRxQ for linux
    3. After succesfully adding path, open your command prompt or bash and run "Bitcoin_Price.py"